@@ -852,7 +852,7 @@ static int
 io_glue_read_cb(GifFileType *gft, GifByteType *buf, int length) {
   io_glue *ig = (io_glue *)gft->UserData;
 
-  return ig->readcb(ig, buf, length);
+  return i_io_read(ig, buf, length);
 }
 
 i_img *
@@ -1037,7 +1037,11 @@ static int do_comments(GifFileType *gf, i_img *img) {
     }
     else {
       char buf[50];
+#ifdef IMAGER_SNPRINTF
+      snprintf(buf, sizeof(buf), "%d", img->tags.tags[pos].idata);
+#else
       sprintf(buf, "%d", img->tags.tags[pos].idata);
+#endif
       if (EGifPutComment(gf, buf) == GIF_ERROR) {
         return 0;
       }
@@ -1768,7 +1772,7 @@ static int
 io_glue_write_cb(GifFileType *gft, const GifByteType *data, int length) {
   io_glue *ig = (io_glue *)gft->UserData;
 
-  return ig->writecb(ig, data, length);
+  return i_io_write(ig, data, length);
 }
 
 
@@ -1796,7 +1800,8 @@ i_writegif_wiol(io_glue *ig, i_quantize *quant, i_img **imgs,
   
   result = i_writegif_low(quant, GifFile, imgs, count);
   
-  ig->closecb(ig);
+  if (i_io_close(ig))
+    return 0;
   
   return result;
 }
@@ -1887,7 +1892,11 @@ static char const *gif_error_msg(int code) {
     return "Unexpected EOF - invalid file";
 
   default:
+#ifdef IMAGER_SNPRINTF
+    snprintf(msg, sizeof(msg), "Unknown giflib error code %d", code);
+#else
     sprintf(msg, "Unknown giflib error code %d", code);
+#endif
     return msg;
   }
 }
