@@ -5,7 +5,7 @@ imgdouble.c - implements double per sample images
 
 =head1 SYNOPSIS
 
-  i_img *im = i_img_double_new(int x, int y, int channels);
+  i_img *im = i_img_double_new(width, height, channels);
   # use like a normal image
 
 =head1 DESCRIPTION
@@ -23,17 +23,17 @@ sample image type to work with.
 #include "imager.h"
 #include "imageri.h"
 
-static int i_ppix_ddoub(i_img *im, int x, int y, const i_color *val);
-static int i_gpix_ddoub(i_img *im, int x, int y, i_color *val);
-static int i_glin_ddoub(i_img *im, int l, int r, int y, i_color *vals);
-static int i_plin_ddoub(i_img *im, int l, int r, int y, const i_color *vals);
-static int i_ppixf_ddoub(i_img *im, int x, int y, const i_fcolor *val);
-static int i_gpixf_ddoub(i_img *im, int x, int y, i_fcolor *val);
-static int i_glinf_ddoub(i_img *im, int l, int r, int y, i_fcolor *vals);
-static int i_plinf_ddoub(i_img *im, int l, int r, int y, const i_fcolor *vals);
-static int i_gsamp_ddoub(i_img *im, int l, int r, int y, i_sample_t *samps, 
+static int i_ppix_ddoub(i_img *im, i_img_dim x, i_img_dim y, const i_color *val);
+static int i_gpix_ddoub(i_img *im, i_img_dim x, i_img_dim y, i_color *val);
+static i_img_dim i_glin_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, i_color *vals);
+static i_img_dim i_plin_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, const i_color *vals);
+static int i_ppixf_ddoub(i_img *im, i_img_dim x, i_img_dim y, const i_fcolor *val);
+static int i_gpixf_ddoub(i_img *im, i_img_dim x, i_img_dim y, i_fcolor *val);
+static i_img_dim i_glinf_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, i_fcolor *vals);
+static i_img_dim i_plinf_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, const i_fcolor *vals);
+static i_img_dim i_gsamp_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, i_sample_t *samps, 
                        int const *chans, int chan_count);
-static int i_gsampf_ddoub(i_img *im, int l, int r, int y, i_fsample_t *samps, 
+static i_img_dim i_gsampf_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, i_fsample_t *samps, 
                         int const *chans, int chan_count);
 
 /*
@@ -84,7 +84,7 @@ static i_img IIM_base_double_direct =
 };
 
 /*
-=item i_img_double_new(int x, int y, int ch)
+=item i_img_double_new(i_img_dim x, i_img_dim y, int ch)
 =category Image creation/destruction
 =synopsis i_img *img = i_img_double_new(width, height, channels);
 
@@ -92,11 +92,12 @@ Creates a new double per sample image.
 
 =cut
 */
-i_img *i_img_double_new(int x, int y, int ch) {
-  int bytes;
+i_img *i_img_double_new(i_img_dim x, i_img_dim y, int ch) {
+  size_t bytes;
   i_img *im;
 
-  mm_log((1,"i_img_double_new(x %d, y %d, ch %d)\n", x, y, ch));
+  mm_log((1,"i_img_double_new(x %" i_DF ", y %" i_DF ", ch %d)\n",
+	  i_DFc(x), i_DFc(y), ch));
 
   if (x < 1 || y < 1) {
     i_push_error(0, "Image sizes must be positive");
@@ -127,8 +128,9 @@ i_img *i_img_double_new(int x, int y, int ch) {
   return im;
 }
 
-static int i_ppix_ddoub(i_img *im, int x, int y, const i_color *val) {
-  int off, ch;
+static int i_ppix_ddoub(i_img *im, i_img_dim x, i_img_dim y, const i_color *val) {
+  i_img_dim off;
+  int ch;
 
   if (x < 0 || x >= im->xsize || y < 0 || y >= im->ysize) 
     return -1;
@@ -147,8 +149,9 @@ static int i_ppix_ddoub(i_img *im, int x, int y, const i_color *val) {
   return 0;
 }
 
-static int i_gpix_ddoub(i_img *im, int x, int y, i_color *val) {
-  int off, ch;
+static int i_gpix_ddoub(i_img *im, i_img_dim x, i_img_dim y, i_color *val) {
+  i_img_dim off;
+  int ch;
 
   if (x < 0 || x >= im->xsize || y < 0 || y >= im->ysize) 
     return -1;
@@ -160,8 +163,9 @@ static int i_gpix_ddoub(i_img *im, int x, int y, i_color *val) {
   return 0;
 }
 
-static int i_ppixf_ddoub(i_img *im, int x, int y, const i_fcolor *val) {
-  int off, ch;
+static int i_ppixf_ddoub(i_img *im, i_img_dim x, i_img_dim y, const i_fcolor *val) {
+  i_img_dim off;
+  int ch;
 
   if (x < 0 || x >= im->xsize || y < 0 || y >= im->ysize) 
     return -1;
@@ -180,8 +184,9 @@ static int i_ppixf_ddoub(i_img *im, int x, int y, const i_fcolor *val) {
   return 0;
 }
 
-static int i_gpixf_ddoub(i_img *im, int x, int y, i_fcolor *val) {
-  int off, ch;
+static int i_gpixf_ddoub(i_img *im, i_img_dim x, i_img_dim y, i_fcolor *val) {
+  i_img_dim off;
+  int ch;
 
   if (x < 0 || x >= im->xsize || y < 0 || y >= im->ysize) 
     return -1;
@@ -193,9 +198,10 @@ static int i_gpixf_ddoub(i_img *im, int x, int y, i_fcolor *val) {
   return 0;
 }
 
-static int i_glin_ddoub(i_img *im, int l, int r, int y, i_color *vals) {
-  int ch, count, i;
-  int off;
+static i_img_dim i_glin_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, i_color *vals) {
+  int ch;
+  i_img_dim count, i;
+  i_img_dim off;
   if (y >=0 && y < im->ysize && l < im->xsize && l >= 0) {
     if (r > im->xsize)
       r = im->xsize;
@@ -214,9 +220,10 @@ static int i_glin_ddoub(i_img *im, int l, int r, int y, i_color *vals) {
   }
 }
 
-static int i_plin_ddoub(i_img *im, int l, int r, int y, const i_color *vals) {
-  int ch, count, i;
-  int off;
+static i_img_dim i_plin_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, const i_color *vals) {
+  int ch;
+  i_img_dim count, i;
+  i_img_dim off;
   if (y >=0 && y < im->ysize && l < im->xsize && l >= 0) {
     if (r > im->xsize)
       r = im->xsize;
@@ -246,9 +253,10 @@ static int i_plin_ddoub(i_img *im, int l, int r, int y, const i_color *vals) {
   }
 }
 
-static int i_glinf_ddoub(i_img *im, int l, int r, int y, i_fcolor *vals) {
-  int ch, count, i;
-  int off;
+static i_img_dim i_glinf_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, i_fcolor *vals) {
+  int ch;
+  i_img_dim count, i;
+  i_img_dim off;
   if (y >=0 && y < im->ysize && l < im->xsize && l >= 0) {
     if (r > im->xsize)
       r = im->xsize;
@@ -267,9 +275,10 @@ static int i_glinf_ddoub(i_img *im, int l, int r, int y, i_fcolor *vals) {
   }
 }
 
-static int i_plinf_ddoub(i_img *im, int l, int r, int y, const i_fcolor *vals) {
-  int ch, count, i;
-  int off;
+static i_img_dim i_plinf_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, const i_fcolor *vals) {
+  int ch;
+  i_img_dim count, i;
+  i_img_dim off;
   if (y >=0 && y < im->ysize && l < im->xsize && l >= 0) {
     if (r > im->xsize)
       r = im->xsize;
@@ -299,10 +308,11 @@ static int i_plinf_ddoub(i_img *im, int l, int r, int y, const i_fcolor *vals) {
   }
 }
 
-static int i_gsamp_ddoub(i_img *im, int l, int r, int y, i_sample_t *samps, 
+static i_img_dim i_gsamp_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, i_sample_t *samps, 
                        int const *chans, int chan_count) {
-  int ch, count, i, w;
-  int off;
+  int ch;
+  i_img_dim count, i, w;
+  i_img_dim off;
 
   if (y >=0 && y < im->ysize && l < im->xsize && l >= 0) {
     if (r > im->xsize)
@@ -349,10 +359,11 @@ static int i_gsamp_ddoub(i_img *im, int l, int r, int y, i_sample_t *samps,
   }
 }
 
-static int i_gsampf_ddoub(i_img *im, int l, int r, int y, i_fsample_t *samps, 
+static i_img_dim i_gsampf_ddoub(i_img *im, i_img_dim l, i_img_dim r, i_img_dim y, i_fsample_t *samps, 
                         int const *chans, int chan_count) {
-  int ch, count, i, w;
-  int off;
+  int ch;
+  i_img_dim count, i, w;
+  i_img_dim off;
 
   if (y >=0 && y < im->ysize && l < im->xsize && l >= 0) {
     if (r > im->xsize)
@@ -415,7 +426,7 @@ i_img *
 i_img_to_drgb(i_img *im) {
   i_img *targ;
   i_fcolor *line;
-  int y;
+  i_img_dim y;
 
   targ = i_img_double_new(im->xsize, im->ysize, im->channels);
   if (!targ)
